@@ -1,6 +1,6 @@
 use anyhow::Result;
 use clap::{Arg, Command};
-use onepage::{init, SiteBuilder, SiteServer, PAGE_DIR};
+use onepage::{init, SiteBuilder, SiteServer, STARTER_TEMPLATE_URL};
 
 fn main() -> Result<(), anyhow::Error> {
     let matches = Command::new("onepage")
@@ -11,8 +11,6 @@ fn main() -> Result<(), anyhow::Error> {
         .subcommand(
             Command::new("init").about("Initialize the site").arg(
                 Arg::new("dir")
-                    .short('d')
-                    .long("dir")
                     .value_name("DIR")
                     .default_value("./onepage")
                     .help("The directory to initilize the site"),
@@ -25,11 +23,11 @@ fn main() -> Result<(), anyhow::Error> {
     match matches.subcommand() {
         Some(("init", arg_matches)) => {
             let dir = arg_matches.value_of("dir").unwrap();
-            init(dir)?;
+            init(dir, STARTER_TEMPLATE_URL)?;
             Ok(())
         }
         Some(("build", _)) => {
-            let mut site = SiteBuilder::new(PAGE_DIR);
+            let mut site = SiteBuilder::new();
             site.build()?;
 
             Ok(())
@@ -42,19 +40,3 @@ fn main() -> Result<(), anyhow::Error> {
         _ => unreachable!(),
     }
 }
-
-#[cfg(test)]
-mod tests {
-
-    #[test]
-    fn test_walkdir() {
-        walkdir::WalkDir::new("pages/posts")
-            .into_iter()
-            .filter_map(|e| e.ok())
-            .filter(|e| e.file_type().is_file())
-            .filter(|e| e.path().display().to_string().ends_with(".md"))
-            .for_each(|e| {
-                println!("====> {}", e.path().display());
-            });
-    }
-}
